@@ -1,7 +1,7 @@
 package Validator::Custom;
 use Object::Simple -base;
 use 5.008001;
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 
 use Carp 'croak';
 use Validator::Custom::Constraint;
@@ -12,7 +12,7 @@ use Validator::Custom::Constraints;
 has ['data_filter', 'rule', 'rule_obj'];
 has error_stock => 1;
 
-sub create_rule { Validator::Custom::Rule->new }
+sub create_rule { Validator::Custom::Rule->new(validator => shift) }
 
 sub js_fill_form_button {
   my ($self, $rule) = @_;
@@ -160,6 +160,7 @@ sub new {
     selected_at_least => \&Validator::Custom::Constraint::selected_at_least,
     shift             => \&Validator::Custom::Constraint::shift_array,
     space             => \&Validator::Custom::Constraint::space,
+    string            => \&Validator::Custom::Constraint::string,
     to_array          => \&Validator::Custom::Constraint::to_array,
     trim              => \&Validator::Custom::Constraint::trim,
     trim_collapse     => \&Validator::Custom::Constraint::trim_collapse,
@@ -236,7 +237,7 @@ sub validate {
     $self->rule_obj($rule);
   }
   else {
-    my $rule_obj = Validator::Custom::Rule->new;
+    my $rule_obj = $self->create_rule;
     $rule_obj->parse($rule, $shared_rule);
     $self->rule_obj($rule_obj);
   }
@@ -254,12 +255,12 @@ sub validate {
     # Key, options, and constraints
     my $key = $r->{key};
     my $opts = $r->{option};
-    my $constraints = $r->{constraints};
+    my $cinfos = $r->{constraints} || [];
     
     # Check constraints
     croak "Invalid rule structure"
-      unless ref $constraints eq 'ARRAY';
-    
+      unless ref $cinfos eq 'ARRAY';
+
     # Arrange key
     my $result_key = $key;
     if (ref $key eq 'HASH') {
@@ -318,51 +319,21 @@ sub validate {
     my $value = @$keys > 1
       ? [map { $data->{$_} } @$keys]
       : $data->{$keys->[0]};
-
-    for my $c (@$constraints) {
-      
-      # Arrange constraint information
-      my $constraint = $c->{constraint};
-      my $message = $c->{message};
-      
-      # Data type
-      my $data_type = {};
-      
-      # Arguments
-      my $arg;
-      
-      # Arrange constraint
-      if(ref $constraint eq 'HASH') {
-        my $first_key = (keys %$constraint)[0];
-        $arg        = $constraint->{$first_key};
-        $constraint = $first_key;
-      }
+    
+    for my $cinfo (@$cinfos) {
       
+      # Constraint information
+      my $args = $cinfo->{args};
+      my $message = $cinfo->{message};
+                                      
       # Constraint function
-      my $cfuncs;
-      my $negative;
-      
-      # Sub reference
-      if( ref $constraint eq 'CODE') {
-        # Constraint function
-        $cfuncs = [$constraint];
-      }
-      
-      # Constraint key
-      else {
-        # Constraint information
-        my $cinfo = $self->_parse_constraint($constraint);
-        $data_type->{array} = 1 if $cinfo->{array};
-                                        
-        # Constraint function
-        $cfuncs = $cinfo->{funcs};
-      }
+      my $cfuncs = $cinfo->{funcs};
       
       # Is valid?
       my $is_valid;
       
       # Data is array
-      if($data_type->{array}) {
+      if($cinfo->{array}) {
           
         # To array
         $value = [$value] unless ref $value eq 'ARRAY';
@@ -374,6 +345,7 @@ sub validate {
           # Validation
           for (my $j = 0; $j < @$cfuncs; $j++) {
             my $cfunc = $cfuncs->[$j];
+            my $arg = $args->[$j];
             
             # Validate
             my $cresult;
@@ -408,7 +380,9 @@ sub validate {
       # Data is scalar
       else {
         # Validation
-        for my $cfunc (@$cfuncs) {
+        for (my $k = 0; $k < @$cfuncs; $k++) {
+          my $cfunc = $cfuncs->[$k];
+          my $arg = $args->[$k];
         
           my $cresult;
           {
@@ -450,7 +424,7 @@ sub validate {
           $result->{_error_infos}->{$result_key} = {
             message      => $message,
             position     => $pos,
-            reason       => $constraint,
+            reason       => $cinfo->{original_constraint},
             original_key => $key
           } unless exists $result->{_error_infos}->{$result_key};
           
@@ -485,75 +459,88 @@ sub validate {
 }
 
 sub _parse_constraint {
-  my ($self, $constraint) = @_;
-  
+  my ($self, $c) = @_;
+
   # Constraint information
   my $cinfo = {};
-  
-  # Simple constraint name
-  unless ($constraint =~ /\W/) {
-    my $cfunc = $self->constraints->{$constraint} || '';
-    croak qq{"$constraint" is not registered}
-      unless ref $cfunc eq 'CODE';
-    $cinfo->{funcs} = [$cfunc];
-    return $cinfo;
-  }
 
-  # Trim space
-  $constraint ||= '';
-  $constraint =~ s/^\s+//;
-  $constraint =~ s/\s+$//;
+  # Arrange constraint information
+  my $constraint = $c->{constraint};
+  $cinfo->{message} = $c->{message};
+  $cinfo->{original_constraint} = $c->{constraint};
   
-  # Target is array elements
-  $cinfo->{array} = 1 if $constraint =~ s/^@//;
-  croak qq{"\@" must be one at the top of constrinat name}
-    if index($constraint, '@') > -1;
-  
-  # Constraint functions
-  my @cfuncs;
-  
-  # Constraint names
-  my @cnames = split(/\|\|/, $constraint);
-  
-  # Convert constraint names to constraint functions
-  for my $cname (@cnames) {
-    $cname ||= '';
-    
-    # Trim space
-    $cname =~ s/^\s+//;
-    $cname =~ s/\s+$//;
-    
-    # Negative
-    my $negative = $cname =~ s/^!// ? 1 : 0;
-    croak qq{"!" must be one at the top of constraint name}
-      if index($cname, '!') > -1;
+  # Code reference
+  if (ref $constraint eq 'CODE') {
+    $cinfo->{funcs} = [$constraint];
+  }
+  # Simple constraint name
+  else {
+    my $constraints;
+    if (ref $constraint eq 'ARRAY') {
+      $constraints = $constraint;
+    }
+    else {
+      if ($constraint =~ /\|\|/) {
+        $constraints = [split(/\|\|/, $constraint)];
+      }
+      else {
+        $constraints = [$constraint];
+      }
+    }
     
-    # Trim space
-    $cname =~ s/^\s+//;
-    $cname =~ s/\s+$//;
-    
-    # Constraint function
-    croak "Constraint name '$cname' must be [A-Za-z0-9_]"
-      if $cname =~ /\W/;
-    my $cfunc = $self->constraints->{$cname} || '';
-    croak qq{"$cname" is not registered}
-      unless ref $cfunc eq 'CODE';
-    
-    # Negativate
-    my $f = $negative ? sub {
-      my $ret = $cfunc->(@_);
-      if (ref $ret eq 'ARRAY') {
-        $ret->[0] = ! $ret->[0];
-        return $ret;
+    # Constraint functions
+    my @cfuncs;
+    my @cargs;
+    for my $cname (@$constraints) {
+      # Arrange constraint
+      if (ref $cname eq 'HASH') {
+        my $first_key = (keys %$cname)[0];
+        push @cargs, $cname->{$first_key};
+        $cname = $first_key;
       }
-      else { return !$ret }
-    } : $cfunc;
-    
-    # Add
-    push @cfuncs, $f;
+
+      # Target is array elements
+      $cinfo->{array} = 1 if $cname =~ s/^@//;
+      croak qq{"\@" must be one at the top of constrinat name}
+        if index($cname, '@') > -1;
+      
+      
+      # Trim space
+      $cname =~ s/^\s+//;
+      $cname =~ s/\s+$//;
+      
+      # Negative
+      my $negative = $cname =~ s/^!// ? 1 : 0;
+      croak qq{"!" must be one at the top of constraint name}
+        if index($cname, '!') > -1;
+      
+      # Trim space
+      $cname =~ s/^\s+//;
+      $cname =~ s/\s+$//;
+      
+      # Constraint function
+      croak "Constraint name '$cname' must be [A-Za-z0-9_]"
+        if $cname =~ /\W/;
+      my $cfunc = $self->constraints->{$cname} || '';
+      croak qq{"$cname" is not registered}
+        unless ref $cfunc eq 'CODE';
+      
+      # Negativate
+      my $f = $negative ? sub {
+        my $ret = $cfunc->(@_);
+        if (ref $ret eq 'ARRAY') {
+          $ret->[0] = ! $ret->[0];
+          return $ret;
+        }
+        else { return !$ret }
+      } : $cfunc;
+      
+      # Add
+      push @cfuncs, $f;
+    }
+    $cinfo->{funcs} = \@cfuncs;
+    $cinfo->{args} = \@cargs;
   }
-  
-  $cinfo->{funcs} = \@cfuncs;
   
   return $cinfo;
 }
@@ -649,20 +636,16 @@ Validator::Custom - HTML form Validation, easy and flexibly
   my $rule = $vc->create_rule;
   
   # Rule syntax - integer, have error message
-  $rule->require('id')->check(
-    'int'
-  )->message('id should be integer');
+  $rule->require('id')->check('int')->message('id should be integer');
   
-  # Rule syntax - not blank, length is 1 to 5, have error messages
-  $rule->require('name')->check(
-    ['not_blank' => 'name is emtpy'],
-    [{length => [1, 5]} => 'name is too long']
-  );
+  # Rule syntax - string, not blank, length is 1 to 5, have error messages
+  $rule->require('name')
+    ->check('string')->message('name should be string')
+    ->check('not_blank')->message('name is emtpy')
+    ->check({length => [1, 5]})->message('name is too long');
   
   # Rule syntax - value is optional, default is 20
-  $rule->optional('age')->check(
-    'int'
-  )->default(20);
+  $rule->optional('age')->check('int')->default(20);
   
   # Validation
   my $result = $vc->validate($data, $rule);
@@ -680,11 +663,11 @@ Validator::Custom - HTML form Validation, easy and flexibly
     my $value = shift;
     return $_->blank($value) || $_->regex($value, qr/[0-9]+/);
   };
-  $rule->require('age')->check(
-    [$blank_or_number => 'age must be blank or number']
-  );
+  $rule->require('age')
+    ->check($blank_or_number)->message('age must be blank or number')
   
-  # Rule old syntax
+  # Rule old syntax, please use above new syntax.
+  # Old syntax take many miss-typing.
   my $rule = [
     id => {message => 'id should be integer'} => [
       'int'
@@ -749,14 +732,13 @@ Data must be hash reference.
 B<3. Prepare a rule for validation>
 
   my $ruel = $vc->create_rule;
-  $rule->require('age')->message('age must be integer')->check(
-    'not_blank',
-    'int'
-  );
-  $rule->require('name')->check(
-    ['not_blank' => 'name is empty']
-    [{length => [1, 5]} => 'name must be length 1 to 5']
-  );
+  $rule->require('age')
+    ->check('not_blank')
+    ->check('int')->message('age must be integer');
+  
+  $rule->require('name')
+    ->check('not_blank')->message('name is empty')
+    ->check({length => [1, 5]})->message('name must be length 1 to 5');
 
 Please see L<Validator::Custom/"RULE"> about rule syntax.
 
@@ -855,20 +837,15 @@ in the POD of L<Validator::Custom::Result>
   my $rule = $vc->create_rule;
   
   # Rule syntax - integer, have error message
-  $rule->require('id')->check(
-    'int'
-  )->message('id should be integer');
+  $rule->require('id')->check('int')->message('id should be integer');
   
   # Rule syntax - not blank, length is 1 to 5, have error messages
-  $rule->require('name')->check(
-    ['not_blank' => 'name is emtpy'],
-    [{length => [1, 5]} => 'name is too long']
-  );
+  $rule->require('name')
+    ->check('not_blank')->message('name is emtpy')
+    ->check({length => [1, 5]})->message('name is too long');
   
   # Rule syntax - value is optional, default is 20
-  $rule->optional('age')->check(
-    'int'
-  )->default(20);
+  $rule->optional('age')->check('int')->default(20);
 
 Rule is L<Validator::Custom::Rule> ojbect.
 You can create C<create_rule> method of L<Validator::Custom>.
@@ -918,16 +895,13 @@ Default to 1. Parameter value is copied to the data.
 
 You set constraints by C<check> method.
 
-  $rule->require('age')->check(
-    {'length' => [1, 5]}
-  );
+  $rule->require('age')->check({'length' => [1, 5]});
 
 You can set message for each constraint function
 
-  $rule->require('name')->check(
-    ['not_blank' => 'name must be not blank'],
-    [{length => [1, 5]} => 'name must be 1 to 5 length']
-  );
+  $rule->require('name')
+    ->check('not_blank')->message('name must be not blank')
+    ->check({length => [1, 5]})->message('name must be 1 to 5 length');
 
 You can create original constraint function using
 original constraints.
@@ -949,7 +923,7 @@ you can call constraints from $_ in subroutine.
 Multiple parameters validation is available.
 
   Data: {password1 => 'xxx', password2 => 'xxx'}
-  Rule: require([qw/password1 password2/])->name('password_check)
+  Rule: $rule->require([qw/password1 password2/])->name('password_check)
           ->check('duplication')
 
 In this example, We check if 'password1' and 'password2' is same.
@@ -963,7 +937,7 @@ This is used by L<Validator::Result> object.
 You can also use the reference of regular expression if you need.
 
   Data: {person1 => 'Taro', person2 => 'Rika', person3 => 'Ken'}
-  Rule: require(qr/^person/)->name('merged_person')
+  Rule: $rule->require(qr/^person/)->name('merged_person')
           ->check('merge') # TaroRikaKen
 
 All matched value is passed to constraint function as array reference.
@@ -975,7 +949,7 @@ In this example, the following value is passed.
 
 You can negative a constraint function
 
-  Rule: require('age')->check('!int')
+  Rule: $rule->require('age')->check('!int')
 
 "!" is added to the head of the constraint name
 if you negative a constraint function.
@@ -983,25 +957,31 @@ if you negative a constraint function.
 
 In this example, 
 
-=head3 "OR" of constraint functions
+=head3 "OR" condition
 
-You can create "OR" of constraint functions
+You can create "OR" condition by using C<check_or> method.
 
-  Rule: require('email')->check('blank || email')
+  Rule: $rule->require('email')->check_or('blank', 'email');
 
-Use "||" to create "OR" of constraint functions.
-'blank || email' means 'blank' or 'email'.
+Check is ok if email value is blank or email.
 
-You can combine "||" and "!".
+The folloing way is old syntax. Please use above syntax.
 
-  Rule: require('email')->check('blank || !int')
+  Rule: $rule->require('email')->check('blank || email')
 
 =head3 Array validation
 
 You can check if all the elements of array is valid.
 
   Data: {nums => [1, 2, 3]}
-  Rule: require('nums')->check('@int')
+  Rule: $rule->require('nums')->array(1)->check('int')
+
+If nums is one value, this is automatically convert to array.
+
+The following is old syntax. Please use above syntax.
+
+  Data: {nums => [1, 2, 3]}
+  Rule: $rule->require('nums')->check('@int')
 
 "@" is added to the head of constraint function name
 to validate all the elements of array.
@@ -1216,7 +1196,7 @@ Default to 1.
 =head2 ascii
 
   Data: {name => 'Ken'}
-  Rule: require('name')->check('ascii')
+  Rule: $rule->require('name')->check('ascii')
 
 Ascii graphic characters(hex 21-7e).
 
@@ -1224,21 +1204,21 @@ Ascii graphic characters(hex 21-7e).
 
   # Check (1, 2, .. 19, 20)
   Data: {age => 19}
-  Rule: require('age')->check({between => [1, 20]})
+  Rule: $rule->require('age')->check({between => [1, 20]})
 
 Between A and B.
 
 =head2 blank
 
   Data: {name => ''}
-  Rule: require('name')->check('blank')
+  Rule: $rule->require('name')->check('blank')
 
 Blank.
 
 =head2 decimal
   
   Data: {num1 => '123', num2 => '1.45'}
-  Rule: require('num1')->check({'decimal' => 3})
+  Rule: $rule->require('num1')->check({'decimal' => 3})
         require('num2')->check({'decimal' => [1, 2]})
 
 Decimal. You can specify maximum digits number at before
@@ -1247,14 +1227,14 @@ and after '.'.
 =head2 defined
 
   Data: {name => 'Ken'}
-  Rule: require('name')->check('defined')
+  Rule: $rule->require('name')->check('defined')
 
 Defined.
 
 =head2 duplication
 
   Data: {mail1 => 'a@somehost.com', mail2 => 'a@somehost.com'};
-  Rule: require(['mail1', 'mail2'])->name('mail')->check('duplication)
+  Rule: $rule->require(['mail1', 'mail2'])->name('mail')->check('duplication)
 
 Check if the two data are same or not.
 
@@ -1268,35 +1248,35 @@ result of validation is false.
 =head2 equal_to
 
   Data: {price => 1000}
-  Rule: require('price')->check({'equal_to' => 1000})
+  Rule: $rule->require('price')->check({'equal_to' => 1000})
 
 Numeric equal comparison.
 
 =head2 greater_than
 
   Data: {price => 1000}
-  Rule: require('price')->check({'greater_than' => 900})
+  Rule: $rule->require('price')->check({'greater_than' => 900})
 
 Numeric "greater than" comparison
 
 =head2 http_url
 
   Data: {url => 'http://somehost.com'};
-  Rule: require('url')->check('http_url')
+  Rule: $rule->require('url')->check('http_url')
 
 HTTP(or HTTPS) URL.
 
 =head2 int
 
   Data: {age => 19};
-  Rule: require('age')->check('int')
+  Rule: $rule->require('age')->check('int')
 
 Integer.
 
 =head2 in_array
 
   Data: {food => 'sushi'};
-  Rule: require('food')->check({'in_array' => [qw/sushi bread apple/]})
+  Rule: $rule->require('food')->check({'in_array' => [qw/sushi bread apple/]})
 
 Check if the values is in array.
 
@@ -1322,28 +1302,28 @@ if value is byte string, length is byte length.
 =head2 less_than
 
   Data: {num => 20}
-  Rule: require('num')->check({'less_than' => 25});
+  Rule: $rule->require('num')->check({'less_than' => 25});
 
 Numeric "less than" comparison.
 
 =head2 not_blank
 
   Data: {name => 'Ken'}
-  Rule: require('name')->check('not_blank') # Except for ''
+  Rule: $rule->require('name')->check('not_blank') # Except for ''
 
 Not blank.
 
 =head2 not_defined
 
   Data: {name => 'Ken'}
-  Rule: require('name')->check('not_defined')
+  Rule: $rule->require('name')->check('not_defined')
 
 Not defined.
 
 =head2 not_space
 
   Data: {name => 'Ken'}
-  Rule: require('name')->check('not_space') # Except for '', ' ', '   '
+  Rule: $rule->require('name')->check('not_space') # Except for '', ' ', '   '
 
 Not contain only space characters. 
 Not that space is only C<[ \t\n\r\f]>
@@ -1352,30 +1332,38 @@ which don't contain unicode space character.
 =head2 space
 
   Data: {name => '   '}
-  Rule: require('name')->check('space') # '', ' ', '   '
+  Rule: $rule->require('name')->check('space') # '', ' ', '   '
 
 White space or empty string.
 Not that space is only C<[ \t\n\r\f]>
 which don't contain unicode space character.
 
+=head2 string
+
+  Data: {name => 'abc'}
+  Rule: $rule->require('name')->check('string') # '', 'abc', 0, 1, 1.23
+
+Check if the value is string, which contain numeric value.
+if value is not defined or reference, this check return false.
+
 =head2 uint
 
   Data: {age => 19}
-  Rule: require('age')->check('uint')
+  Rule: $rule->require('age')->check('uint')
 
 Unsigned integer(contain zero).
   
 =head2 regex
 
   Data: {num => '123'}
-  Rule: require('num')->check({'regex' => qr/\d{0,3}/})
+  Rule: $rule->require('num')->check({'regex' => qr/\d{0,3}/})
 
 Match a regular expression.
 
 =head2 selected_at_least
 
   Data: {hobby => ['music', 'movie' ]}
-  Rule: require('hobby')->check({selected_at_least => 1})
+  Rule: $rule->require('hobby')->check({selected_at_least => 1})
 
 Selected at least specified count item.
 In other word, the array contains at least specified count element.
@@ -1385,7 +1373,7 @@ In other word, the array contains at least specified count element.
 =head2 date_to_timepiece
 
   Data: {date => '2010/11/12'}
-  Rule: require('date')->check('date_to_timepiece')
+  Rule: $rule->require('date')->check('date_to_timepiece')
 
 The value which looks like date is converted
 to L<Time::Piece> object.
@@ -1400,7 +1388,7 @@ If the value contains 8 digits, the value is assumed date.
 And year and month and mday combination is ok.
 
   Data: {year => 2011, month => 3, mday => 9}
-  Rule: require(['year', 'month', 'mday'])->name('date')
+  Rule: $rule->require(['year', 'month', 'mday'])->name('date')
                                           ->check('date_to_timepiece')
 
 You can get result value.
@@ -1412,7 +1400,7 @@ Note that L<Time::Piece> is required.
 =head2 datetime_to_timepiece
 
   Data: {datetime => '2010/11/12 12:14:45'}
-  Rule: require('datetime')->check('datetime_to_timepiece');
+  Rule: $rule->require('datetime')->check('datetime_to_timepiece');
 
 The value which looks like date and time is converted
 to L<Time::Piece> object.
@@ -1428,7 +1416,7 @@ And year and month and mday combination is ok.
 
   Data: {year => 2011, month => 3, mday => 9
          hour => 10, min => 30, sec => 30}
-  Rule: require(['year', 'month', 'mday', 'hour', 'min', 'sec'])
+  Rule: $rule->require(['year', 'month', 'mday', 'hour', 'min', 'sec'])
           ->name('datetime')->check('datetime_to_timepiece')
 
 You can get result value.
@@ -1440,7 +1428,7 @@ Note that L<Time::Piece> is required.
 =head2 merge
 
   Data: {name1 => 'Ken', name2 => 'Rika', name3 => 'Taro'}
-  Rule: require(['name1', 'name2', 'name3'])->name('mergd_name')
+  Rule: $rule->require(['name1', 'name2', 'name3'])->name('mergd_name')
           ->check('merge') # KenRikaTaro
 
 Merge the values.
@@ -1454,14 +1442,14 @@ Note that if one value is not defined, merged value become undefined.
 =head2 shift
 
   Data: {names => ['Ken', 'Taro']}
-  Rule: require('names')->check('shift') # 'Ken'
+  Rule: $rule->require('names')->check('shift') # 'Ken'
 
 Shift the head element of array.
 
 =head2 to_array
 
   Data: {languages => 'Japanese'}
-  Rule: require('languages')->check('to_array') # ['Japanese']
+  Rule: $rule->require('languages')->check('to_array') # ['Japanese']
   
 Convert non array reference data to array reference.
 This is useful to check checkbox values or select multiple values.
@@ -1469,7 +1457,7 @@ This is useful to check checkbox values or select multiple values.
 =head2 trim
 
   Data: {name => '  Ken  '}
-  Rule: require('name')->check('trim') # 'Ken'
+  Rule: $rule->require('name')->check('trim') # 'Ken'
 
 Trim leading and trailing white space.
 Not that trim only C<[ \t\n\r\f]>
@@ -1478,7 +1466,7 @@ which don't contain unicode space character.
 =head2 trim_collapse
 
   Data: {name => '  Ken   Takagi  '}
-  Rule: require('name')->check('trim_collapse') # 'Ken Takagi'
+  Rule: $rule->require('name')->check('trim_collapse') # 'Ken Takagi'
 
 Trim leading and trailing white space,
 and collapse all whitespace characters into a single space.
@@ -1488,7 +1476,7 @@ which don't contain unicode space character.
 =head2 trim_lead
 
   Data: {name => '  Ken  '}
-  Rule: require('name')->check('trim_lead') # 'Ken  '
+  Rule: $rule->require('name')->check('trim_lead') # 'Ken  '
 
 Trim leading white space.
 Not that trim only C<[ \t\n\r\f]>
@@ -1497,7 +1485,7 @@ which don't contain unicode space character.
 =head2 trim_trail
 
   Data: {name => '  Ken  '}
-  Rule: require('name')->check('trim_trail') # '  Ken'
+  Rule: $rule->require('name')->check('trim_trail') # '  Ken'
 
 Trim trailing white space.
 Not that trim only C<[ \t\n\r\f]>
@@ -1506,28 +1494,28 @@ which don't contain unicode space character.
 =head2 trim_uni
 
   Data: {name => '  Ken  '}
-  Rule: require('name')->check('trim_uni') # 'Ken'
+  Rule: $rule->require('name')->check('trim_uni') # 'Ken'
 
 Trim leading and trailing white space, which contain unicode space character.
 
 =head2 trim_uni_collapse
 
   Data: {name => '  Ken   Takagi  '};
-  Rule: require('name')->check('trim_uni_collapse') # 'Ken Takagi'
+  Rule: $rule->require('name')->check('trim_uni_collapse') # 'Ken Takagi'
 
 Trim leading and trailing white space, which contain unicode space character.
 
 =head2 trim_uni_lead
 
   Data: {name => '  Ken  '};
-  Rule: require('name')->check('trim_uni_lead') # 'Ken  '
+  Rule: $rule->require('name')->check('trim_uni_lead') # 'Ken  '
 
 Trim leading white space, which contain unicode space character.
 
 =head2 trim_uni_trail
   
   Data: {name => '  Ken  '};
-  Rule: require('name')->check('trim_uni_trail') # '  Ken'
+  Rule: $rule->require('name')->check('trim_uni_trail') # '  Ken'
 
 Trim trailing white space, which contain unicode space character.
 
@@ -1688,12 +1676,13 @@ L<Validator::Custom::Result>
   error_infos # Removed at 2017/1/1 
 
   # Methods
+  error_reason # Removed at 2017/1/1
   add_error_info # Removed at 2017/1/1
   error # Removed at 2017/1/1
   errors # Removed at 2017/1/1
   errors_to_hash # Removed at 2017/1/1
   invalid_keys # Removed at 2017/1/1
-  remove_error_info# Removed at 2017/1/1
+  remove_error_info # Removed at 2017/1/1
 
 =head1 BACKWORD COMPATIBLE POLICY
 
