@@ -1,8 +1,39 @@
 package Validator::Custom::Rule;
 use Object::Simple -base;
+use Carp 'croak';
 
 has 'topic';
 has 'rule' => sub { [] };
+has 'validator';
+
+sub array {
+  my $self = shift;
+  
+  if (@_) {
+    $self->topic->{array} = $_[0];
+    return $self;
+  }
+  else {
+    return $self->topic->{array};
+  }
+  
+  return $self;
+}
+
+sub check_or {
+  my ($self, @constraints) = @_;
+  
+  my $constraint_h = {};
+  $constraint_h->{constraint} = \@constraints;
+  
+  my $cinfo = $self->validator->_parse_constraint($constraint_h);
+  $cinfo->{array} = $self->topic->{array};
+  
+  $self->topic->{constraints} ||= [];
+  push @{$self->topic->{constraints}}, $cinfo;
+  
+  return $self;
+}
 
 sub check {
   my ($self, @constraints) = @_;
@@ -17,10 +48,13 @@ sub check {
     else {
       $constraint_h->{constraint} = $constraint;
     }
-    push @$constraints_h, $constraint_h;
+    my $cinfo = $self->validator->_parse_constraint($constraint_h);
+    $cinfo->{array} = $self->topic->{array};
+    push @$constraints_h, $cinfo;
   }
-  
-  $self->topic->{constraints} = $constraints_h;
+
+  $self->topic->{constraints} ||= [];
+  $self->topic->{constraints} = [@{$self->topic->{constraints}}, @{$constraints_h}];
   
   return $self;
 }
@@ -44,7 +78,10 @@ sub default {
 sub message {
   my ($self, $message) = @_;
   
-  $self->topic->{option}{message} = $message;
+  my $constraints = $self->topic->{constraints} || [];
+  for my $constraint (@$constraints) {
+    $constraint->{message} ||= $message;
+  }
   
   return $self;
 }
@@ -124,7 +161,7 @@ sub parse {
         else {
           $constraint_h->{constraint} = $constraint;
         }
-        push @$constraints_h, $constraint_h;
+        push @$constraints_h, $self->validator->_parse_constraint($constraint_h);
       }
     } else {
       $constraints_h = {
@@ -191,14 +228,23 @@ Content of rule object.
 
 =head1 METHODS
 
+=head2 array
+
+  $rule->array(1);
+
+Tell current topic data structure is array.
+
 =head2 check
 
-  $rule->check(
-    'not_blank',
-    'ascii'
-  );
+  $rule->check('not_blank')->check('ascii');
 
-Set constraints.
+Add constraints to current topic.
+
+=head2 check_or
+
+  $rule->check_or('not_blank', 'ascii');
+
+Add "or" condition constraints to current topic.
 
 =head2 copy
 
@@ -214,9 +260,18 @@ Set default option
 
 =head2 message
 
-  $rule->message('Error');
+  $rule->require('name')
+    ->check('not_blank')->message('should be not blank')
+    ->check('int')->message('should be int');
 
-Set message option
+Set message for each check.
+
+Message is fallback to before check
+so you can write the following way.
+
+  $rule->require('name')
+    ->check('not_blank')
+    ->check('int')->message('should be not blank and int');
 
 =head2 name
 
